==> blitz-js-view-1.0.1.tgz: package/controllers/view.js <==
/**
 * Generic Dependencies
 */
const util = require("util")
const fs = require("fs")
const readFile = util.promisify(fs.readFile)
const path = require("path")

/**
 * Load API node connection which will be used for server-side data-fetching
 * Without this, we'd have to create a new instance on every request
 */
const Blitz = require('blitz-js-query')
const api = new Blitz({
  api_url: blitz.config.view.client.apiUrl,
  auth_url: blitz.config.view.client.authUrl,
  user_key: blitz.config.view.core.userKey,
  user_secret: blitz.config.view.core.userSecret
})

/**
 * Render Dependencies
 */
const sourcePath = blitz.config.view.sourcePath
const publicPath = blitz.config.view.core.publicPath
const createBundleRenderer = require("vue-server-renderer").createBundleRenderer

/**
 * View Controller rendering data into templates
 */
class ViewController {
  /**
   * Render View with data from Endpoint. Returns the html back to the endpoint
   */
  async render(url, data) {
    const serverBundle = require(path.join(publicPath, "vue-ssr-server-bundle.json"))
    const clientManifest = require(path.join(publicPath, "vue-ssr-client-manifest.json"))
    const template = await readFile(path.join(__dirname, "../vue/index.template.html"), "utf-8")
    const renderer = createBundleRenderer(serverBundle, {
      template,
      clientManifest,
      runInNewContext: false
    })
    const render = util.promisify(renderer.renderToString)
    const context = {
      url,
      data,
      api
    }
    return await render(context)
  }
}

module.exports = new ViewController

==> blitz-js-view-1.0.2.tgz: package/controllers/view.js <==
/**
 * Generic Dependencies
 */
const util = require("util")
const fs = require("fs")
const readFile = util.promisify(fs.readFile)
const path = require("path")

/**
 * Load API node connection which will be used for server-side data-fetching
 * Without this, we'd have to create a new instance on every request
 */
const Blitz = require('blitz-js-query')
const api = new Blitz({
  api_url: blitz.config.view.core.apiUrl,
  auth_url: blitz.config.view.core.authUrl,
  user_key: blitz.config.view.core.userKey,
  user_secret: blitz.config.view.core.userSecret
})

/**
 * Render Dependencies
 */
const sourcePath = blitz.config.view.sourcePath
const publicPath = blitz.config.view.core.publicPath
const createBundleRenderer = require("vue-server-renderer").createBundleRenderer

/**
 * View Controller rendering data into templates
 */
class ViewController {
  /**
   * Render View with data from Endpoint. Returns the html back to the endpoint
   */
  async render(url, data) {
    const serverBundle = require(path.join(publicPath, "vue-ssr-server-bundle.json"))
    const clientManifest = require(path.join(publicPath, "vue-ssr-client-manifest.json"))
    const template = await readFile(path.join(__dirname, "../vue/index.template.html"), "utf-8")
    const renderer = createBundleRenderer(serverBundle, {
      template,
      clientManifest,
      runInNewContext: false
    })
    const render = util.promisify(renderer.renderToString)
    const context = {
      url,
      data,
      api
    }
    return await render(context)
  }
}

module.exports = new ViewController
